import type { BaseContract, BigNumberish, BytesLike, FunctionFragment, Result, Interface, EventFragment, AddressLike, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedLogDescription, TypedListener, TypedContractMethod } from "../../../common";
export interface ICTokenInterface extends Interface {
    getFunction(nameOrSignature: "_acceptAdmin" | "_reduceReserves" | "_setComptroller" | "_setDiscountRate" | "_setInterestRateModel" | "_setPendingAdmin" | "_setReserveFactor" | "accrualBlockNumber" | "accrueInterest" | "allowance" | "approve" | "balanceOf" | "balanceOfUnderlying" | "borrowBalanceCurrent" | "borrowBalanceStored" | "borrowRatePerBlock" | "exchangeRateCurrent" | "exchangeRateStored" | "getAccountSnapshot" | "getCash" | "getDiscountRate" | "seize" | "supplyRatePerBlock" | "totalBorrowsCurrent" | "totalSupply" | "transfer" | "transferFrom"): FunctionFragment;
    getEvent(nameOrSignatureOrTopic: "AccrueInterest" | "Approval" | "Borrow" | "LiquidateBorrow" | "Mint" | "NewAdmin" | "NewComptroller" | "NewDiscountRate" | "NewMarketInterestRateModel" | "NewPendingAdmin" | "NewReserveFactor" | "Redeem" | "RepayBorrow" | "ReservesAdded" | "ReservesReduced" | "Transfer"): EventFragment;
    encodeFunctionData(functionFragment: "_acceptAdmin", values?: undefined): string;
    encodeFunctionData(functionFragment: "_reduceReserves", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "_setComptroller", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "_setDiscountRate", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "_setInterestRateModel", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "_setPendingAdmin", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "_setReserveFactor", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "accrualBlockNumber", values?: undefined): string;
    encodeFunctionData(functionFragment: "accrueInterest", values?: undefined): string;
    encodeFunctionData(functionFragment: "allowance", values: [AddressLike, AddressLike]): string;
    encodeFunctionData(functionFragment: "approve", values: [AddressLike, BigNumberish]): string;
    encodeFunctionData(functionFragment: "balanceOf", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "balanceOfUnderlying", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "borrowBalanceCurrent", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "borrowBalanceStored", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "borrowRatePerBlock", values?: undefined): string;
    encodeFunctionData(functionFragment: "exchangeRateCurrent", values?: undefined): string;
    encodeFunctionData(functionFragment: "exchangeRateStored", values?: undefined): string;
    encodeFunctionData(functionFragment: "getAccountSnapshot", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "getCash", values?: undefined): string;
    encodeFunctionData(functionFragment: "getDiscountRate", values?: undefined): string;
    encodeFunctionData(functionFragment: "seize", values: [AddressLike, AddressLike, BigNumberish]): string;
    encodeFunctionData(functionFragment: "supplyRatePerBlock", values?: undefined): string;
    encodeFunctionData(functionFragment: "totalBorrowsCurrent", values?: undefined): string;
    encodeFunctionData(functionFragment: "totalSupply", values?: undefined): string;
    encodeFunctionData(functionFragment: "transfer", values: [AddressLike, BigNumberish]): string;
    encodeFunctionData(functionFragment: "transferFrom", values: [AddressLike, AddressLike, BigNumberish]): string;
    decodeFunctionResult(functionFragment: "_acceptAdmin", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "_reduceReserves", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "_setComptroller", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "_setDiscountRate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "_setInterestRateModel", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "_setPendingAdmin", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "_setReserveFactor", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "accrualBlockNumber", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "accrueInterest", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "allowance", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "approve", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "balanceOf", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "balanceOfUnderlying", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "borrowBalanceCurrent", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "borrowBalanceStored", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "borrowRatePerBlock", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "exchangeRateCurrent", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "exchangeRateStored", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getAccountSnapshot", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getCash", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getDiscountRate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "seize", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "supplyRatePerBlock", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "totalBorrowsCurrent", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "totalSupply", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "transfer", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "transferFrom", data: BytesLike): Result;
}
export declare namespace AccrueInterestEvent {
    type InputTuple = [
        cashPrior: BigNumberish,
        interestAccumulated: BigNumberish,
        borrowIndex: BigNumberish,
        totalBorrows: BigNumberish
    ];
    type OutputTuple = [
        cashPrior: bigint,
        interestAccumulated: bigint,
        borrowIndex: bigint,
        totalBorrows: bigint
    ];
    interface OutputObject {
        cashPrior: bigint;
        interestAccumulated: bigint;
        borrowIndex: bigint;
        totalBorrows: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace ApprovalEvent {
    type InputTuple = [
        owner: AddressLike,
        spender: AddressLike,
        amount: BigNumberish
    ];
    type OutputTuple = [owner: string, spender: string, amount: bigint];
    interface OutputObject {
        owner: string;
        spender: string;
        amount: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace BorrowEvent {
    type InputTuple = [
        borrower: AddressLike,
        borrowAmount: BigNumberish,
        accountBorrows: BigNumberish,
        totalBorrows: BigNumberish
    ];
    type OutputTuple = [
        borrower: string,
        borrowAmount: bigint,
        accountBorrows: bigint,
        totalBorrows: bigint
    ];
    interface OutputObject {
        borrower: string;
        borrowAmount: bigint;
        accountBorrows: bigint;
        totalBorrows: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace LiquidateBorrowEvent {
    type InputTuple = [
        liquidator: AddressLike,
        borrower: AddressLike,
        repayAmount: BigNumberish,
        cTokenCollateral: AddressLike,
        seizeTokens: BigNumberish
    ];
    type OutputTuple = [
        liquidator: string,
        borrower: string,
        repayAmount: bigint,
        cTokenCollateral: string,
        seizeTokens: bigint
    ];
    interface OutputObject {
        liquidator: string;
        borrower: string;
        repayAmount: bigint;
        cTokenCollateral: string;
        seizeTokens: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace MintEvent {
    type InputTuple = [
        minter: AddressLike,
        mintAmount: BigNumberish,
        mintTokens: BigNumberish
    ];
    type OutputTuple = [
        minter: string,
        mintAmount: bigint,
        mintTokens: bigint
    ];
    interface OutputObject {
        minter: string;
        mintAmount: bigint;
        mintTokens: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace NewAdminEvent {
    type InputTuple = [oldAdmin: AddressLike, newAdmin: AddressLike];
    type OutputTuple = [oldAdmin: string, newAdmin: string];
    interface OutputObject {
        oldAdmin: string;
        newAdmin: string;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace NewComptrollerEvent {
    type InputTuple = [
        oldComptroller: AddressLike,
        newComptroller: AddressLike
    ];
    type OutputTuple = [oldComptroller: string, newComptroller: string];
    interface OutputObject {
        oldComptroller: string;
        newComptroller: string;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace NewDiscountRateEvent {
    type InputTuple = [
        oldDiscountRateMantissa: BigNumberish,
        newDiscountRateMantissa: BigNumberish
    ];
    type OutputTuple = [
        oldDiscountRateMantissa: bigint,
        newDiscountRateMantissa: bigint
    ];
    interface OutputObject {
        oldDiscountRateMantissa: bigint;
        newDiscountRateMantissa: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace NewMarketInterestRateModelEvent {
    type InputTuple = [
        oldInterestRateModel: AddressLike,
        newInterestRateModel: AddressLike
    ];
    type OutputTuple = [
        oldInterestRateModel: string,
        newInterestRateModel: string
    ];
    interface OutputObject {
        oldInterestRateModel: string;
        newInterestRateModel: string;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace NewPendingAdminEvent {
    type InputTuple = [
        oldPendingAdmin: AddressLike,
        newPendingAdmin: AddressLike
    ];
    type OutputTuple = [oldPendingAdmin: string, newPendingAdmin: string];
    interface OutputObject {
        oldPendingAdmin: string;
        newPendingAdmin: string;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace NewReserveFactorEvent {
    type InputTuple = [
        oldReserveFactorMantissa: BigNumberish,
        newReserveFactorMantissa: BigNumberish
    ];
    type OutputTuple = [
        oldReserveFactorMantissa: bigint,
        newReserveFactorMantissa: bigint
    ];
    interface OutputObject {
        oldReserveFactorMantissa: bigint;
        newReserveFactorMantissa: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace RedeemEvent {
    type InputTuple = [
        redeemer: AddressLike,
        redeemAmount: BigNumberish,
        redeemTokens: BigNumberish
    ];
    type OutputTuple = [
        redeemer: string,
        redeemAmount: bigint,
        redeemTokens: bigint
    ];
    interface OutputObject {
        redeemer: string;
        redeemAmount: bigint;
        redeemTokens: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace RepayBorrowEvent {
    type InputTuple = [
        payer: AddressLike,
        borrower: AddressLike,
        repayAmount: BigNumberish,
        accountBorrows: BigNumberish,
        totalBorrows: BigNumberish
    ];
    type OutputTuple = [
        payer: string,
        borrower: string,
        repayAmount: bigint,
        accountBorrows: bigint,
        totalBorrows: bigint
    ];
    interface OutputObject {
        payer: string;
        borrower: string;
        repayAmount: bigint;
        accountBorrows: bigint;
        totalBorrows: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace ReservesAddedEvent {
    type InputTuple = [
        benefactor: AddressLike,
        addAmount: BigNumberish,
        newTotalReserves: BigNumberish
    ];
    type OutputTuple = [
        benefactor: string,
        addAmount: bigint,
        newTotalReserves: bigint
    ];
    interface OutputObject {
        benefactor: string;
        addAmount: bigint;
        newTotalReserves: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace ReservesReducedEvent {
    type InputTuple = [
        admin: AddressLike,
        reduceAmount: BigNumberish,
        newTotalReserves: BigNumberish
    ];
    type OutputTuple = [
        admin: string,
        reduceAmount: bigint,
        newTotalReserves: bigint
    ];
    interface OutputObject {
        admin: string;
        reduceAmount: bigint;
        newTotalReserves: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace TransferEvent {
    type InputTuple = [
        from: AddressLike,
        to: AddressLike,
        amount: BigNumberish
    ];
    type OutputTuple = [from: string, to: string, amount: bigint];
    interface OutputObject {
        from: string;
        to: string;
        amount: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export interface ICToken extends BaseContract {
    connect(runner?: ContractRunner | null): ICToken;
    waitForDeployment(): Promise<this>;
    interface: ICTokenInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    _acceptAdmin: TypedContractMethod<[], [bigint], "nonpayable">;
    _reduceReserves: TypedContractMethod<[
        reduceAmount: BigNumberish
    ], [
        bigint
    ], "nonpayable">;
    _setComptroller: TypedContractMethod<[
        newComptroller: AddressLike
    ], [
        bigint
    ], "nonpayable">;
    _setDiscountRate: TypedContractMethod<[
        discountRateMantissa: BigNumberish
    ], [
        bigint
    ], "nonpayable">;
    _setInterestRateModel: TypedContractMethod<[
        newInterestRateModel: AddressLike
    ], [
        bigint
    ], "nonpayable">;
    _setPendingAdmin: TypedContractMethod<[
        newPendingAdmin: AddressLike
    ], [
        bigint
    ], "nonpayable">;
    _setReserveFactor: TypedContractMethod<[
        newReserveFactorMantissa: BigNumberish
    ], [
        bigint
    ], "nonpayable">;
    accrualBlockNumber: TypedContractMethod<[], [bigint], "nonpayable">;
    accrueInterest: TypedContractMethod<[], [bigint], "nonpayable">;
    allowance: TypedContractMethod<[
        owner: AddressLike,
        spender: AddressLike
    ], [
        bigint
    ], "view">;
    approve: TypedContractMethod<[
        spender: AddressLike,
        amount: BigNumberish
    ], [
        boolean
    ], "nonpayable">;
    balanceOf: TypedContractMethod<[owner: AddressLike], [bigint], "view">;
    balanceOfUnderlying: TypedContractMethod<[
        owner: AddressLike
    ], [
        bigint
    ], "nonpayable">;
    borrowBalanceCurrent: TypedContractMethod<[
        account: AddressLike
    ], [
        bigint
    ], "nonpayable">;
    borrowBalanceStored: TypedContractMethod<[
        account: AddressLike
    ], [
        bigint
    ], "view">;
    borrowRatePerBlock: TypedContractMethod<[], [bigint], "view">;
    exchangeRateCurrent: TypedContractMethod<[], [bigint], "nonpayable">;
    exchangeRateStored: TypedContractMethod<[], [bigint], "view">;
    getAccountSnapshot: TypedContractMethod<[
        account: AddressLike
    ], [
        [bigint, bigint, bigint, bigint]
    ], "view">;
    getCash: TypedContractMethod<[], [bigint], "view">;
    getDiscountRate: TypedContractMethod<[], [bigint], "view">;
    seize: TypedContractMethod<[
        liquidator: AddressLike,
        borrower: AddressLike,
        seizeTokens: BigNumberish
    ], [
        bigint
    ], "nonpayable">;
    supplyRatePerBlock: TypedContractMethod<[], [bigint], "view">;
    totalBorrowsCurrent: TypedContractMethod<[], [bigint], "nonpayable">;
    totalSupply: TypedContractMethod<[], [bigint], "view">;
    transfer: TypedContractMethod<[
        dst: AddressLike,
        amount: BigNumberish
    ], [
        boolean
    ], "nonpayable">;
    transferFrom: TypedContractMethod<[
        src: AddressLike,
        dst: AddressLike,
        amount: BigNumberish
    ], [
        boolean
    ], "nonpayable">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "_acceptAdmin"): TypedContractMethod<[], [bigint], "nonpayable">;
    getFunction(nameOrSignature: "_reduceReserves"): TypedContractMethod<[reduceAmount: BigNumberish], [bigint], "nonpayable">;
    getFunction(nameOrSignature: "_setComptroller"): TypedContractMethod<[newComptroller: AddressLike], [bigint], "nonpayable">;
    getFunction(nameOrSignature: "_setDiscountRate"): TypedContractMethod<[
        discountRateMantissa: BigNumberish
    ], [
        bigint
    ], "nonpayable">;
    getFunction(nameOrSignature: "_setInterestRateModel"): TypedContractMethod<[
        newInterestRateModel: AddressLike
    ], [
        bigint
    ], "nonpayable">;
    getFunction(nameOrSignature: "_setPendingAdmin"): TypedContractMethod<[
        newPendingAdmin: AddressLike
    ], [
        bigint
    ], "nonpayable">;
    getFunction(nameOrSignature: "_setReserveFactor"): TypedContractMethod<[
        newReserveFactorMantissa: BigNumberish
    ], [
        bigint
    ], "nonpayable">;
    getFunction(nameOrSignature: "accrualBlockNumber"): TypedContractMethod<[], [bigint], "nonpayable">;
    getFunction(nameOrSignature: "accrueInterest"): TypedContractMethod<[], [bigint], "nonpayable">;
    getFunction(nameOrSignature: "allowance"): TypedContractMethod<[
        owner: AddressLike,
        spender: AddressLike
    ], [
        bigint
    ], "view">;
    getFunction(nameOrSignature: "approve"): TypedContractMethod<[
        spender: AddressLike,
        amount: BigNumberish
    ], [
        boolean
    ], "nonpayable">;
    getFunction(nameOrSignature: "balanceOf"): TypedContractMethod<[owner: AddressLike], [bigint], "view">;
    getFunction(nameOrSignature: "balanceOfUnderlying"): TypedContractMethod<[owner: AddressLike], [bigint], "nonpayable">;
    getFunction(nameOrSignature: "borrowBalanceCurrent"): TypedContractMethod<[account: AddressLike], [bigint], "nonpayable">;
    getFunction(nameOrSignature: "borrowBalanceStored"): TypedContractMethod<[account: AddressLike], [bigint], "view">;
    getFunction(nameOrSignature: "borrowRatePerBlock"): TypedContractMethod<[], [bigint], "view">;
    getFunction(nameOrSignature: "exchangeRateCurrent"): TypedContractMethod<[], [bigint], "nonpayable">;
    getFunction(nameOrSignature: "exchangeRateStored"): TypedContractMethod<[], [bigint], "view">;
    getFunction(nameOrSignature: "getAccountSnapshot"): TypedContractMethod<[
        account: AddressLike
    ], [
        [bigint, bigint, bigint, bigint]
    ], "view">;
    getFunction(nameOrSignature: "getCash"): TypedContractMethod<[], [bigint], "view">;
    getFunction(nameOrSignature: "getDiscountRate"): TypedContractMethod<[], [bigint], "view">;
    getFunction(nameOrSignature: "seize"): TypedContractMethod<[
        liquidator: AddressLike,
        borrower: AddressLike,
        seizeTokens: BigNumberish
    ], [
        bigint
    ], "nonpayable">;
    getFunction(nameOrSignature: "supplyRatePerBlock"): TypedContractMethod<[], [bigint], "view">;
    getFunction(nameOrSignature: "totalBorrowsCurrent"): TypedContractMethod<[], [bigint], "nonpayable">;
    getFunction(nameOrSignature: "totalSupply"): TypedContractMethod<[], [bigint], "view">;
    getFunction(nameOrSignature: "transfer"): TypedContractMethod<[
        dst: AddressLike,
        amount: BigNumberish
    ], [
        boolean
    ], "nonpayable">;
    getFunction(nameOrSignature: "transferFrom"): TypedContractMethod<[
        src: AddressLike,
        dst: AddressLike,
        amount: BigNumberish
    ], [
        boolean
    ], "nonpayable">;
    getEvent(key: "AccrueInterest"): TypedContractEvent<AccrueInterestEvent.InputTuple, AccrueInterestEvent.OutputTuple, AccrueInterestEvent.OutputObject>;
    getEvent(key: "Approval"): TypedContractEvent<ApprovalEvent.InputTuple, ApprovalEvent.OutputTuple, ApprovalEvent.OutputObject>;
    getEvent(key: "Borrow"): TypedContractEvent<BorrowEvent.InputTuple, BorrowEvent.OutputTuple, BorrowEvent.OutputObject>;
    getEvent(key: "LiquidateBorrow"): TypedContractEvent<LiquidateBorrowEvent.InputTuple, LiquidateBorrowEvent.OutputTuple, LiquidateBorrowEvent.OutputObject>;
    getEvent(key: "Mint"): TypedContractEvent<MintEvent.InputTuple, MintEvent.OutputTuple, MintEvent.OutputObject>;
    getEvent(key: "NewAdmin"): TypedContractEvent<NewAdminEvent.InputTuple, NewAdminEvent.OutputTuple, NewAdminEvent.OutputObject>;
    getEvent(key: "NewComptroller"): TypedContractEvent<NewComptrollerEvent.InputTuple, NewComptrollerEvent.OutputTuple, NewComptrollerEvent.OutputObject>;
    getEvent(key: "NewDiscountRate"): TypedContractEvent<NewDiscountRateEvent.InputTuple, NewDiscountRateEvent.OutputTuple, NewDiscountRateEvent.OutputObject>;
    getEvent(key: "NewMarketInterestRateModel"): TypedContractEvent<NewMarketInterestRateModelEvent.InputTuple, NewMarketInterestRateModelEvent.OutputTuple, NewMarketInterestRateModelEvent.OutputObject>;
    getEvent(key: "NewPendingAdmin"): TypedContractEvent<NewPendingAdminEvent.InputTuple, NewPendingAdminEvent.OutputTuple, NewPendingAdminEvent.OutputObject>;
    getEvent(key: "NewReserveFactor"): TypedContractEvent<NewReserveFactorEvent.InputTuple, NewReserveFactorEvent.OutputTuple, NewReserveFactorEvent.OutputObject>;
    getEvent(key: "Redeem"): TypedContractEvent<RedeemEvent.InputTuple, RedeemEvent.OutputTuple, RedeemEvent.OutputObject>;
    getEvent(key: "RepayBorrow"): TypedContractEvent<RepayBorrowEvent.InputTuple, RepayBorrowEvent.OutputTuple, RepayBorrowEvent.OutputObject>;
    getEvent(key: "ReservesAdded"): TypedContractEvent<ReservesAddedEvent.InputTuple, ReservesAddedEvent.OutputTuple, ReservesAddedEvent.OutputObject>;
    getEvent(key: "ReservesReduced"): TypedContractEvent<ReservesReducedEvent.InputTuple, ReservesReducedEvent.OutputTuple, ReservesReducedEvent.OutputObject>;
    getEvent(key: "Transfer"): TypedContractEvent<TransferEvent.InputTuple, TransferEvent.OutputTuple, TransferEvent.OutputObject>;
    filters: {
        "AccrueInterest(uint256,uint256,uint256,uint256)": TypedContractEvent<AccrueInterestEvent.InputTuple, AccrueInterestEvent.OutputTuple, AccrueInterestEvent.OutputObject>;
        AccrueInterest: TypedContractEvent<AccrueInterestEvent.InputTuple, AccrueInterestEvent.OutputTuple, AccrueInterestEvent.OutputObject>;
        "Approval(address,address,uint256)": TypedContractEvent<ApprovalEvent.InputTuple, ApprovalEvent.OutputTuple, ApprovalEvent.OutputObject>;
        Approval: TypedContractEvent<ApprovalEvent.InputTuple, ApprovalEvent.OutputTuple, ApprovalEvent.OutputObject>;
        "Borrow(address,uint256,uint256,uint256)": TypedContractEvent<BorrowEvent.InputTuple, BorrowEvent.OutputTuple, BorrowEvent.OutputObject>;
        Borrow: TypedContractEvent<BorrowEvent.InputTuple, BorrowEvent.OutputTuple, BorrowEvent.OutputObject>;
        "LiquidateBorrow(address,address,uint256,address,uint256)": TypedContractEvent<LiquidateBorrowEvent.InputTuple, LiquidateBorrowEvent.OutputTuple, LiquidateBorrowEvent.OutputObject>;
        LiquidateBorrow: TypedContractEvent<LiquidateBorrowEvent.InputTuple, LiquidateBorrowEvent.OutputTuple, LiquidateBorrowEvent.OutputObject>;
        "Mint(address,uint256,uint256)": TypedContractEvent<MintEvent.InputTuple, MintEvent.OutputTuple, MintEvent.OutputObject>;
        Mint: TypedContractEvent<MintEvent.InputTuple, MintEvent.OutputTuple, MintEvent.OutputObject>;
        "NewAdmin(address,address)": TypedContractEvent<NewAdminEvent.InputTuple, NewAdminEvent.OutputTuple, NewAdminEvent.OutputObject>;
        NewAdmin: TypedContractEvent<NewAdminEvent.InputTuple, NewAdminEvent.OutputTuple, NewAdminEvent.OutputObject>;
        "NewComptroller(address,address)": TypedContractEvent<NewComptrollerEvent.InputTuple, NewComptrollerEvent.OutputTuple, NewComptrollerEvent.OutputObject>;
        NewComptroller: TypedContractEvent<NewComptrollerEvent.InputTuple, NewComptrollerEvent.OutputTuple, NewComptrollerEvent.OutputObject>;
        "NewDiscountRate(uint256,uint256)": TypedContractEvent<NewDiscountRateEvent.InputTuple, NewDiscountRateEvent.OutputTuple, NewDiscountRateEvent.OutputObject>;
        NewDiscountRate: TypedContractEvent<NewDiscountRateEvent.InputTuple, NewDiscountRateEvent.OutputTuple, NewDiscountRateEvent.OutputObject>;
        "NewMarketInterestRateModel(address,address)": TypedContractEvent<NewMarketInterestRateModelEvent.InputTuple, NewMarketInterestRateModelEvent.OutputTuple, NewMarketInterestRateModelEvent.OutputObject>;
        NewMarketInterestRateModel: TypedContractEvent<NewMarketInterestRateModelEvent.InputTuple, NewMarketInterestRateModelEvent.OutputTuple, NewMarketInterestRateModelEvent.OutputObject>;
        "NewPendingAdmin(address,address)": TypedContractEvent<NewPendingAdminEvent.InputTuple, NewPendingAdminEvent.OutputTuple, NewPendingAdminEvent.OutputObject>;
        NewPendingAdmin: TypedContractEvent<NewPendingAdminEvent.InputTuple, NewPendingAdminEvent.OutputTuple, NewPendingAdminEvent.OutputObject>;
        "NewReserveFactor(uint256,uint256)": TypedContractEvent<NewReserveFactorEvent.InputTuple, NewReserveFactorEvent.OutputTuple, NewReserveFactorEvent.OutputObject>;
        NewReserveFactor: TypedContractEvent<NewReserveFactorEvent.InputTuple, NewReserveFactorEvent.OutputTuple, NewReserveFactorEvent.OutputObject>;
        "Redeem(address,uint256,uint256)": TypedContractEvent<RedeemEvent.InputTuple, RedeemEvent.OutputTuple, RedeemEvent.OutputObject>;
        Redeem: TypedContractEvent<RedeemEvent.InputTuple, RedeemEvent.OutputTuple, RedeemEvent.OutputObject>;
        "RepayBorrow(address,address,uint256,uint256,uint256)": TypedContractEvent<RepayBorrowEvent.InputTuple, RepayBorrowEvent.OutputTuple, RepayBorrowEvent.OutputObject>;
        RepayBorrow: TypedContractEvent<RepayBorrowEvent.InputTuple, RepayBorrowEvent.OutputTuple, RepayBorrowEvent.OutputObject>;
        "ReservesAdded(address,uint256,uint256)": TypedContractEvent<ReservesAddedEvent.InputTuple, ReservesAddedEvent.OutputTuple, ReservesAddedEvent.OutputObject>;
        ReservesAdded: TypedContractEvent<ReservesAddedEvent.InputTuple, ReservesAddedEvent.OutputTuple, ReservesAddedEvent.OutputObject>;
        "ReservesReduced(address,uint256,uint256)": TypedContractEvent<ReservesReducedEvent.InputTuple, ReservesReducedEvent.OutputTuple, ReservesReducedEvent.OutputObject>;
        ReservesReduced: TypedContractEvent<ReservesReducedEvent.InputTuple, ReservesReducedEvent.OutputTuple, ReservesReducedEvent.OutputObject>;
        "Transfer(address,address,uint256)": TypedContractEvent<TransferEvent.InputTuple, TransferEvent.OutputTuple, TransferEvent.OutputObject>;
        Transfer: TypedContractEvent<TransferEvent.InputTuple, TransferEvent.OutputTuple, TransferEvent.OutputObject>;
    };
}
