import type { BaseContract, BigNumberish, FunctionFragment, Interface, EventFragment, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedLogDescription, TypedListener } from "../../common";
export interface TokenErrorReporterInterface extends Interface {
    getEvent(nameOrSignatureOrTopic: "Failure"): EventFragment;
}
export declare namespace FailureEvent {
    type InputTuple = [
        error: BigNumberish,
        info: BigNumberish,
        detail: BigNumberish
    ];
    type OutputTuple = [error: bigint, info: bigint, detail: bigint];
    interface OutputObject {
        error: bigint;
        info: bigint;
        detail: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export interface TokenErrorReporter extends BaseContract {
    connect(runner?: ContractRunner | null): TokenErrorReporter;
    waitForDeployment(): Promise<this>;
    interface: TokenErrorReporterInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getEvent(key: "Failure"): TypedContractEvent<FailureEvent.InputTuple, FailureEvent.OutputTuple, FailureEvent.OutputObject>;
    filters: {
        "Failure(uint256,uint256,uint256)": TypedContractEvent<FailureEvent.InputTuple, FailureEvent.OutputTuple, FailureEvent.OutputObject>;
        Failure: TypedContractEvent<FailureEvent.InputTuple, FailureEvent.OutputTuple, FailureEvent.OutputObject>;
    };
}
