import type { BaseContract, BigNumberish, BytesLike, FunctionFragment, Result, Interface, EventFragment, AddressLike, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedLogDescription, TypedListener, TypedContractMethod } from "../common";
export interface ITimelockInterface extends Interface {
    getFunction(nameOrSignature: "createAgreement" | "isSupport"): FunctionFragment;
    getEvent(nameOrSignatureOrTopic: "AgreementClaimed" | "AgreementCreated" | "AgreementFrozen" | "RescueERC20" | "TimeLockFrozen"): EventFragment;
    encodeFunctionData(functionFragment: "createAgreement", values: [BigNumberish, AddressLike, BigNumberish, AddressLike]): string;
    encodeFunctionData(functionFragment: "isSupport", values: [AddressLike]): string;
    decodeFunctionResult(functionFragment: "createAgreement", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isSupport", data: BytesLike): Result;
}
export declare namespace AgreementClaimedEvent {
    type InputTuple = [
        agreementId: BigNumberish,
        actionType: BigNumberish,
        asset: AddressLike,
        amount: BigNumberish,
        beneficiary: AddressLike
    ];
    type OutputTuple = [
        agreementId: bigint,
        actionType: bigint,
        asset: string,
        amount: bigint,
        beneficiary: string
    ];
    interface OutputObject {
        agreementId: bigint;
        actionType: bigint;
        asset: string;
        amount: bigint;
        beneficiary: string;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace AgreementCreatedEvent {
    type InputTuple = [
        agreementId: BigNumberish,
        actionType: BigNumberish,
        asset: AddressLike,
        amount: BigNumberish,
        beneficiary: AddressLike,
        releaseTime: BigNumberish
    ];
    type OutputTuple = [
        agreementId: bigint,
        actionType: bigint,
        asset: string,
        amount: bigint,
        beneficiary: string,
        releaseTime: bigint
    ];
    interface OutputObject {
        agreementId: bigint;
        actionType: bigint;
        asset: string;
        amount: bigint;
        beneficiary: string;
        releaseTime: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace AgreementFrozenEvent {
    type InputTuple = [agreementId: BigNumberish, value: boolean];
    type OutputTuple = [agreementId: bigint, value: boolean];
    interface OutputObject {
        agreementId: bigint;
        value: boolean;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace RescueERC20Event {
    type InputTuple = [
        token: AddressLike,
        to: AddressLike,
        amount: BigNumberish
    ];
    type OutputTuple = [token: string, to: string, amount: bigint];
    interface OutputObject {
        token: string;
        to: string;
        amount: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace TimeLockFrozenEvent {
    type InputTuple = [value: boolean];
    type OutputTuple = [value: boolean];
    interface OutputObject {
        value: boolean;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export interface ITimelock extends BaseContract {
    connect(runner?: ContractRunner | null): ITimelock;
    waitForDeployment(): Promise<this>;
    interface: ITimelockInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    createAgreement: TypedContractMethod<[
        actionType: BigNumberish,
        underlying: AddressLike,
        amount: BigNumberish,
        beneficiary: AddressLike
    ], [
        bigint
    ], "nonpayable">;
    isSupport: TypedContractMethod<[underlying: AddressLike], [boolean], "view">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "createAgreement"): TypedContractMethod<[
        actionType: BigNumberish,
        underlying: AddressLike,
        amount: BigNumberish,
        beneficiary: AddressLike
    ], [
        bigint
    ], "nonpayable">;
    getFunction(nameOrSignature: "isSupport"): TypedContractMethod<[underlying: AddressLike], [boolean], "view">;
    getEvent(key: "AgreementClaimed"): TypedContractEvent<AgreementClaimedEvent.InputTuple, AgreementClaimedEvent.OutputTuple, AgreementClaimedEvent.OutputObject>;
    getEvent(key: "AgreementCreated"): TypedContractEvent<AgreementCreatedEvent.InputTuple, AgreementCreatedEvent.OutputTuple, AgreementCreatedEvent.OutputObject>;
    getEvent(key: "AgreementFrozen"): TypedContractEvent<AgreementFrozenEvent.InputTuple, AgreementFrozenEvent.OutputTuple, AgreementFrozenEvent.OutputObject>;
    getEvent(key: "RescueERC20"): TypedContractEvent<RescueERC20Event.InputTuple, RescueERC20Event.OutputTuple, RescueERC20Event.OutputObject>;
    getEvent(key: "TimeLockFrozen"): TypedContractEvent<TimeLockFrozenEvent.InputTuple, TimeLockFrozenEvent.OutputTuple, TimeLockFrozenEvent.OutputObject>;
    filters: {
        "AgreementClaimed(uint256,uint8,address,uint256,address)": TypedContractEvent<AgreementClaimedEvent.InputTuple, AgreementClaimedEvent.OutputTuple, AgreementClaimedEvent.OutputObject>;
        AgreementClaimed: TypedContractEvent<AgreementClaimedEvent.InputTuple, AgreementClaimedEvent.OutputTuple, AgreementClaimedEvent.OutputObject>;
        "AgreementCreated(uint256,uint8,address,uint256,address,uint256)": TypedContractEvent<AgreementCreatedEvent.InputTuple, AgreementCreatedEvent.OutputTuple, AgreementCreatedEvent.OutputObject>;
        AgreementCreated: TypedContractEvent<AgreementCreatedEvent.InputTuple, AgreementCreatedEvent.OutputTuple, AgreementCreatedEvent.OutputObject>;
        "AgreementFrozen(uint256,bool)": TypedContractEvent<AgreementFrozenEvent.InputTuple, AgreementFrozenEvent.OutputTuple, AgreementFrozenEvent.OutputObject>;
        AgreementFrozen: TypedContractEvent<AgreementFrozenEvent.InputTuple, AgreementFrozenEvent.OutputTuple, AgreementFrozenEvent.OutputObject>;
        "RescueERC20(address,address,uint256)": TypedContractEvent<RescueERC20Event.InputTuple, RescueERC20Event.OutputTuple, RescueERC20Event.OutputObject>;
        RescueERC20: TypedContractEvent<RescueERC20Event.InputTuple, RescueERC20Event.OutputTuple, RescueERC20Event.OutputObject>;
        "TimeLockFrozen(bool)": TypedContractEvent<TimeLockFrozenEvent.InputTuple, TimeLockFrozenEvent.OutputTuple, TimeLockFrozenEvent.OutputObject>;
        TimeLockFrozen: TypedContractEvent<TimeLockFrozenEvent.InputTuple, TimeLockFrozenEvent.OutputTuple, TimeLockFrozenEvent.OutputObject>;
    };
}
