import type { BaseContract, BigNumberish, BytesLike, FunctionFragment, Result, Interface, EventFragment, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedLogDescription, TypedListener, TypedContractMethod } from "../../common";
export interface WhitePaperInterestRateModelInterface extends Interface {
    getFunction(nameOrSignature: "baseRatePerBlock" | "blocksPerYear" | "getBorrowRate" | "getSupplyRate" | "isInterestRateModel" | "multiplierPerBlock" | "utilizationRate"): FunctionFragment;
    getEvent(nameOrSignatureOrTopic: "NewInterestParams"): EventFragment;
    encodeFunctionData(functionFragment: "baseRatePerBlock", values?: undefined): string;
    encodeFunctionData(functionFragment: "blocksPerYear", values?: undefined): string;
    encodeFunctionData(functionFragment: "getBorrowRate", values: [BigNumberish, BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "getSupplyRate", values: [BigNumberish, BigNumberish, BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "isInterestRateModel", values?: undefined): string;
    encodeFunctionData(functionFragment: "multiplierPerBlock", values?: undefined): string;
    encodeFunctionData(functionFragment: "utilizationRate", values: [BigNumberish, BigNumberish, BigNumberish]): string;
    decodeFunctionResult(functionFragment: "baseRatePerBlock", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "blocksPerYear", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getBorrowRate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getSupplyRate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isInterestRateModel", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "multiplierPerBlock", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "utilizationRate", data: BytesLike): Result;
}
export declare namespace NewInterestParamsEvent {
    type InputTuple = [
        blocksPerYear: BigNumberish,
        baseRatePerBlock: BigNumberish,
        multiplierPerBlock: BigNumberish
    ];
    type OutputTuple = [
        blocksPerYear: bigint,
        baseRatePerBlock: bigint,
        multiplierPerBlock: bigint
    ];
    interface OutputObject {
        blocksPerYear: bigint;
        baseRatePerBlock: bigint;
        multiplierPerBlock: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export interface WhitePaperInterestRateModel extends BaseContract {
    connect(runner?: ContractRunner | null): WhitePaperInterestRateModel;
    waitForDeployment(): Promise<this>;
    interface: WhitePaperInterestRateModelInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    baseRatePerBlock: TypedContractMethod<[], [bigint], "view">;
    blocksPerYear: TypedContractMethod<[], [bigint], "view">;
    getBorrowRate: TypedContractMethod<[
        cash: BigNumberish,
        borrows: BigNumberish,
        reserves: BigNumberish
    ], [
        bigint
    ], "view">;
    getSupplyRate: TypedContractMethod<[
        cash: BigNumberish,
        borrows: BigNumberish,
        reserves: BigNumberish,
        reserveFactorMantissa: BigNumberish
    ], [
        bigint
    ], "view">;
    isInterestRateModel: TypedContractMethod<[], [boolean], "view">;
    multiplierPerBlock: TypedContractMethod<[], [bigint], "view">;
    utilizationRate: TypedContractMethod<[
        cash: BigNumberish,
        borrows: BigNumberish,
        reserves: BigNumberish
    ], [
        bigint
    ], "view">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "baseRatePerBlock"): TypedContractMethod<[], [bigint], "view">;
    getFunction(nameOrSignature: "blocksPerYear"): TypedContractMethod<[], [bigint], "view">;
    getFunction(nameOrSignature: "getBorrowRate"): TypedContractMethod<[
        cash: BigNumberish,
        borrows: BigNumberish,
        reserves: BigNumberish
    ], [
        bigint
    ], "view">;
    getFunction(nameOrSignature: "getSupplyRate"): TypedContractMethod<[
        cash: BigNumberish,
        borrows: BigNumberish,
        reserves: BigNumberish,
        reserveFactorMantissa: BigNumberish
    ], [
        bigint
    ], "view">;
    getFunction(nameOrSignature: "isInterestRateModel"): TypedContractMethod<[], [boolean], "view">;
    getFunction(nameOrSignature: "multiplierPerBlock"): TypedContractMethod<[], [bigint], "view">;
    getFunction(nameOrSignature: "utilizationRate"): TypedContractMethod<[
        cash: BigNumberish,
        borrows: BigNumberish,
        reserves: BigNumberish
    ], [
        bigint
    ], "view">;
    getEvent(key: "NewInterestParams"): TypedContractEvent<NewInterestParamsEvent.InputTuple, NewInterestParamsEvent.OutputTuple, NewInterestParamsEvent.OutputObject>;
    filters: {
        "NewInterestParams(uint256,uint256,uint256)": TypedContractEvent<NewInterestParamsEvent.InputTuple, NewInterestParamsEvent.OutputTuple, NewInterestParamsEvent.OutputObject>;
        NewInterestParams: TypedContractEvent<NewInterestParamsEvent.InputTuple, NewInterestParamsEvent.OutputTuple, NewInterestParamsEvent.OutputObject>;
    };
}
