import type { BaseContract, BigNumberish, BytesLike, FunctionFragment, Result, Interface, AddressLike, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedListener, TypedContractMethod } from "../../common";
export interface ICErc20Interface extends Interface {
    getFunction(nameOrSignature: "_addReserves" | "borrow" | "liquidateBorrow" | "mint" | "redeem" | "redeemUnderlying" | "repayBorrow" | "repayBorrowBehalf" | "sweepToken"): FunctionFragment;
    encodeFunctionData(functionFragment: "_addReserves", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "borrow", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "liquidateBorrow", values: [AddressLike, BigNumberish, AddressLike]): string;
    encodeFunctionData(functionFragment: "mint", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "redeem", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "redeemUnderlying", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "repayBorrow", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "repayBorrowBehalf", values: [AddressLike, BigNumberish]): string;
    encodeFunctionData(functionFragment: "sweepToken", values: [AddressLike]): string;
    decodeFunctionResult(functionFragment: "_addReserves", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "borrow", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "liquidateBorrow", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "mint", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "redeem", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "redeemUnderlying", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "repayBorrow", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "repayBorrowBehalf", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "sweepToken", data: BytesLike): Result;
}
export interface ICErc20 extends BaseContract {
    connect(runner?: ContractRunner | null): ICErc20;
    waitForDeployment(): Promise<this>;
    interface: ICErc20Interface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    _addReserves: TypedContractMethod<[
        addAmount: BigNumberish
    ], [
        bigint
    ], "nonpayable">;
    borrow: TypedContractMethod<[
        borrowAmount: BigNumberish
    ], [
        bigint
    ], "nonpayable">;
    liquidateBorrow: TypedContractMethod<[
        borrower: AddressLike,
        repayAmount: BigNumberish,
        cTokenCollateral: AddressLike
    ], [
        bigint
    ], "nonpayable">;
    mint: TypedContractMethod<[mintAmount: BigNumberish], [bigint], "nonpayable">;
    redeem: TypedContractMethod<[
        redeemTokens: BigNumberish
    ], [
        bigint
    ], "nonpayable">;
    redeemUnderlying: TypedContractMethod<[
        redeemAmount: BigNumberish
    ], [
        bigint
    ], "nonpayable">;
    repayBorrow: TypedContractMethod<[
        repayAmount: BigNumberish
    ], [
        bigint
    ], "nonpayable">;
    repayBorrowBehalf: TypedContractMethod<[
        borrower: AddressLike,
        repayAmount: BigNumberish
    ], [
        bigint
    ], "nonpayable">;
    sweepToken: TypedContractMethod<[token: AddressLike], [void], "nonpayable">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "_addReserves"): TypedContractMethod<[addAmount: BigNumberish], [bigint], "nonpayable">;
    getFunction(nameOrSignature: "borrow"): TypedContractMethod<[borrowAmount: BigNumberish], [bigint], "nonpayable">;
    getFunction(nameOrSignature: "liquidateBorrow"): TypedContractMethod<[
        borrower: AddressLike,
        repayAmount: BigNumberish,
        cTokenCollateral: AddressLike
    ], [
        bigint
    ], "nonpayable">;
    getFunction(nameOrSignature: "mint"): TypedContractMethod<[mintAmount: BigNumberish], [bigint], "nonpayable">;
    getFunction(nameOrSignature: "redeem"): TypedContractMethod<[redeemTokens: BigNumberish], [bigint], "nonpayable">;
    getFunction(nameOrSignature: "redeemUnderlying"): TypedContractMethod<[redeemAmount: BigNumberish], [bigint], "nonpayable">;
    getFunction(nameOrSignature: "repayBorrow"): TypedContractMethod<[repayAmount: BigNumberish], [bigint], "nonpayable">;
    getFunction(nameOrSignature: "repayBorrowBehalf"): TypedContractMethod<[
        borrower: AddressLike,
        repayAmount: BigNumberish
    ], [
        bigint
    ], "nonpayable">;
    getFunction(nameOrSignature: "sweepToken"): TypedContractMethod<[token: AddressLike], [void], "nonpayable">;
    filters: {};
}
